package com.ruoyi.dz.mapper;

import java.util.List;
import com.ruoyi.dz.domain.DzTeacher;

/**
 * 老师Mapper接口
 * 
 * @author ruoyi
 * @date 2025-09-12
 */
public interface DzTeacherMapper 
{
    /**
     * 查询老师
     * 
     * @param teacherId 老师主键
     * @return 老师
     */
    public DzTeacher selectDzTeacherByTeacherId(Long teacherId);

    /**
     * 根据用户ID查询老师
     * 
     * @param userId 用户ID
     * @return 老师
     */
    public DzTeacher selectDzTeacherByUserId(Long userId);

    /**
     * 查询老师列表
     * 
     * @param dzTeacher 老师
     * @return 老师集合
     */
    public List<DzTeacher> selectDzTeacherList(DzTeacher dzTeacher);

    /**
     * 新增老师
     * 
     * @param dzTeacher 老师
     * @return 结果
     */
    public int insertDzTeacher(DzTeacher dzTeacher);

    /**
     * 修改老师
     * 
     * @param dzTeacher 老师
     * @return 结果
     */
    public int updateDzTeacher(DzTeacher dzTeacher);

    /**
     * 删除老师
     * 
     * @param teacherId 老师主键
     * @return 结果
     */
    public int deleteDzTeacherByTeacherId(Long teacherId);

    /**
     * 批量删除老师
     * 
     * @param teacherIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDzTeacherByTeacherIds(Long[] teacherIds);
}
